#[non_exhaustive]pub enum HttpCachedClientError {
EmptyFile,
Http(HttpError),
Io(IoError),
IsStale(IsStaleError),
}Expand description
A list of errors which may be produced by HttpCachedClient::fetch.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyFile
Returned if the fetched file was empty.
Http(HttpError)
Returned if the HTTP client could not fetch an item
Io(IoError)
Returned in case of an std::io::Error.
IsStale(IsStaleError)
Returned in case it wasn’t possible to check whether the cache file is stale or not.