HttpClient

Struct HttpClient 

pub struct HttpClient { /* private fields */ }
A client to download rust releases data.

If a cached file is not present, or if a cached file is present, but the copy is outdated, the client will download a new copy of the given resource and store it to the cache_folder. If a cached file is present, and the copy is not outdated, the cached file will be returned instead.

Implementations

Source

impl HttpClient

pub fn new(timeout: Duration) -> Self

Create a new HttpClient.

use std::time::Duration;
use rust_releases_io::HttpClient;
let timeout = Duration::from_secs(86_400);

let _client = HttpClient::new(timeout);