pub struct HttpClient { /* private fields */ }Expand description
A client to download rust releases data.
If a cached file is not present, or if a cached file is present, but the copy is outdated,
the client will download a new copy of the given resource and store it to the cache_folder.
If a cached file is present, and the copy is not outdated, the cached file will be returned
instead.
Implementations
Sourceimpl HttpClient
impl HttpClient
Sourcepub fn new(timeout: Duration) -> Self
pub fn new(timeout: Duration) -> Self
Create a new HttpClient.
use std::time::Duration;
use rust_releases_io::HttpClient;
let timeout = Duration::from_secs(86_400);
let _client = HttpClient::new(timeout);Trait Implementations
Sourceimpl Debug for HttpClient
impl Debug for HttpClient
Sourceimpl Default for HttpClient
impl Default for HttpClient
Sourcefn default() -> Self
fn default() -> Self
Create a new HttpClient.
use rust_releases_io::HttpClient;
let _client = HttpClient::default();Sourceimpl RustReleasesClient for HttpClient
impl RustReleasesClient for HttpClient
Sourcetype Error = ClientError
type Error = ClientError
The type of error returned by the client implementation.
Sourcefn fetch(
&self,
resource: ResourceFile<'_, '_>,
) -> Result<RetrievedDocument, Self::Error>
fn fetch( &self, resource: ResourceFile<'_, '_>, ) -> Result<RetrievedDocument, Self::Error>
Fetch the document described by the
resource file.Auto Trait Implementations
impl Freeze for HttpClient
impl !RefUnwindSafe for HttpClient
impl Send for HttpClient
impl Sync for HttpClient
impl Unpin for HttpClient
impl UnsafeUnpin for HttpClient
impl !UnwindSafe for HttpClient